==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/FullStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { FullStochasticOscillatorIndicatorStrategy } from "./FullStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let FullStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class FullStochasticOscillatorIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        get_up() {
            return new FullStochasticOscillatorIndicatorStrategy();
        }
        get up() {
            return this.get_up();
        }
        get_u2() {
            return FullStochasticOscillatorIndicator.$;
        }
        get u2() {
            return this.get_u2();
        }
        get va() {
            return typeGetValue(this.c(FullStochasticOscillatorIndicator.vf));
        }
        set va(a) {
            this.h(FullStochasticOscillatorIndicator.vf, a);
        }
        uv() {
            return this.va;
        }
        u4(a) {
            this.va = a;
        }
        get smoothingPeriod() {
            return typeGetValue(this.c(FullStochasticOscillatorIndicator.vg));
        }
        set smoothingPeriod(a) {
            this.h(FullStochasticOscillatorIndicator.vg, a);
        }
        ux() {
            return this.smoothingPeriod;
        }
        get vc() {
            return typeGetValue(this.c(FullStochasticOscillatorIndicator.vh));
        }
        set vc(a) {
            this.h(FullStochasticOscillatorIndicator.vh, a);
        }
        uu() {
            return this.vc;
        }
        t5() {
            return this.vc;
        }
    }
    FullStochasticOscillatorIndicator.$t = markType(FullStochasticOscillatorIndicator, 'FullStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    FullStochasticOscillatorIndicator.vf = StrategyBasedIndicator.u7(14, FullStochasticOscillatorIndicator.$);
    FullStochasticOscillatorIndicator.vg = StrategyBasedIndicator.u8(3, FullStochasticOscillatorIndicator.$, "SmoothingPeriod");
    FullStochasticOscillatorIndicator.vh = StrategyBasedIndicator.u8(3, FullStochasticOscillatorIndicator.$, "TriggerPeriod");
    return FullStochasticOscillatorIndicator;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/FullStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { FullStochasticOscillatorIndicatorStrategy } from "./FullStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let FullStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class FullStochasticOscillatorIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        get_yy() {
            return new FullStochasticOscillatorIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return FullStochasticOscillatorIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(FullStochasticOscillatorIndicator.zo));
        }
        set zj(a) {
            this.h(FullStochasticOscillatorIndicator.zo, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
        get smoothingPeriod() {
            return typeGetValue(this.c(FullStochasticOscillatorIndicator.zp));
        }
        set smoothingPeriod(a) {
            this.h(FullStochasticOscillatorIndicator.zp, a);
        }
        y6() {
            return this.smoothingPeriod;
        }
        get zl() {
            return typeGetValue(this.c(FullStochasticOscillatorIndicator.zq));
        }
        set zl(a) {
            this.h(FullStochasticOscillatorIndicator.zq, a);
        }
        y3() {
            return this.zl;
        }
        ye() {
            return this.zl;
        }
    }
    FullStochasticOscillatorIndicator.$t = markType(FullStochasticOscillatorIndicator, 'FullStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    FullStochasticOscillatorIndicator.zo = StrategyBasedIndicator.zg(14, FullStochasticOscillatorIndicator.$);
    FullStochasticOscillatorIndicator.zp = StrategyBasedIndicator.zh(3, FullStochasticOscillatorIndicator.$, "SmoothingPeriod");
    FullStochasticOscillatorIndicator.zq = StrategyBasedIndicator.zh(3, FullStochasticOscillatorIndicator.$, "TriggerPeriod");
    return FullStochasticOscillatorIndicator;
})();
